@@ -2,10 +2,10 @@
 from fruit.modules.console import echo, error, warning
 
 # Export decorators
-from fruit.api.decorators import target, step
+from fruit.api.decorators import target, step, provider
 
 # Export exceptions
-from fruit.api.api import abort, finish, skip
+from fruit.api.api import abort, finish, skip, fail
 
 # Export the shell module
 from fruit.api.shell import shell
