@@ -1,5 +1,5 @@
 from fruit.modules.target import FruitError
-from fruit.modules.step import SkipStepSignal
+from fruit.modules.step import SkipStepSignal, FailStepSignal, AbortStepSignal
 from fruit.modules.garden import Garden
 import fruit.modules.console as console
 
@@ -14,10 +14,28 @@ def abort(reason: str):
     
     Raises
     ------
-    FruitError
+    AbortStepSignal
         Error signal for target make 
     """
-    raise FruitError(reason)
+    raise AbortStepSignal(reason)
+
+def fail(reason:str= None) -> None:
+    """
+    Send a signal that the current step is failed, BUT DO not prevent other
+    steps from being executed.
+
+    As `fruit.abort()` stops the make process, the fail function only indicates
+    a step error.
+    
+    Parameters
+    ----------
+    reason : str, optional
+        Reason of the error, by default None
+    """
+    if reason is None:
+        raise  FailStepSignal()
+    else:
+        raise FailStepSignal(reason)
 
 # BUG: Skip propagates...
 def skip(reason: str= None):
