@@ -8,10 +8,17 @@ from tabulate import tabulate
 from fruit.modules.fruitloader import load
 from fruit.modules.garden import Garden
 import fruit.modules.console as console
+import fruit.modules.printing as printing
 
 
+# Import the extensions!
+import fruit.extensions.global_providers
+
 @click.group()
 def cli():
+    """
+    Fruit cli framework for task automation.
+    """
     pass
 
 
@@ -27,34 +34,42 @@ def collect(path:str):
     try:
         # Load the config file
         load(path)
+        # Print the list of targets
+        printing.print_target_list(Garden().get_targets())
 
-        # List the targets
-        tbl = []
+        printing.print_provider_list(Garden().get_providers())
 
-        for trg in Garden().get_targets():
-            tbl.append((trg.name, trg.desc))
-        
-        console.echo(tabulate(tbl, headers=['Target', 'Description']), )
 
     except Exception as err:
         console.error(str(err))
 
-
 @cli.command()
-@click.argument('target', required=True)
+@click.argument('target', required=True, nargs=-1)
 def make(target: str):
     """
     Make a fruit target from the parsed fruitconfig.py file.
     """
-    try:
-        console.echo()
-        console.echo("🍓 Making target '{}'... ".format(target))
-        console.echo()
-        load('.')
+    load('.')
+    # Pass all the targets to the make function
+    Garden().make_multiple(*target)
 
-        Garden().make_target(target)
-    except Exception as err:
-        console.error(str(err))
+@cli.command()
+@click.argument('name', required=True)
+def get(name: str):
+    """Run an information provider to obtain data from the current project.
+    
+    \b
+    Example::
+        fruit get version
+    
+    """
+    try:
+        load('.')
+        result = Garden().run_provider(name=name)
+
+        console.echo(result)
+    except Exception as exc:
+        console.error(str(exc))
 
 
 # Main application code of the project
